@@ -364,10 +364,15 @@ def histplot(
             "markersize": 10.0,
             "elinewidth": 1,
         }
+
+        _xerr: np.ndarray | float | int | None
+
         if xerr is True:
             _xerr = _bin_widths / 2
         elif isinstance(xerr, (int, float)):
             _xerr = xerr
+        else:
+            _xerr = None
 
         for i in range(len(plottables)):
             _plot_info = plottables[i].to_errorbar()
@@ -433,7 +438,7 @@ def hist2dplot(
         Array of per-bin labels to display. If ``True`` will
         display numerical values
     cbar : bool, optional, default True
-        Draw a colorbar. In contrast to mpl behaviours the cbar axes is
+        Draw a colorbar. In contrast to mpl behaviors the cbar axes is
         appended in such a way that it doesn't modify the original axes
         width:height ratio.
     cbarsize : str or float, optional, default "7%"
